pub type WaivedLocations = (Equals<RootLocation>,);Expand description
Locations that will not be charged fees in the executor, either execution or delivery. We only waive fees for system functions, which these locations represent.
pub type WaivedLocations = (Equals<RootLocation>,);Locations that will not be charged fees in the executor, either execution or delivery. We only waive fees for system functions, which these locations represent.